summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/src/cursor
diff options
context:
space:
mode:
authorLuke Chen <luke.chen@mongodb.com>2019-07-05 12:27:29 +1000
committerLuke Chen <luke.chen@mongodb.com>2019-07-05 12:27:29 +1000
commitdaceefe370a71036df6e1ecb209e966d29bc2871 (patch)
tree93d837763bfeb38e8c59bc665742dce99d242e31 /src/third_party/wiredtiger/src/cursor
parent7d88bdb226e8a3dc9b5eb4b57edcca111619c5f9 (diff)
downloadmongo-daceefe370a71036df6e1ecb209e966d29bc2871.tar.gz
Import wiredtiger: b50d65e8560446e2cd205594e07bbcaa2305b144 from branch mongodb-4.2
ref: d86b3a8a33..b50d65e856 for: 4.3.1 WT-4502 Assertion checking hazard pointers on page discard is too strong WT-4733 Change test/format to do longer-term repeatable read testing WT-4743 Fix memory leaks and core dumps in page-split error handling WT-4786 Coverity: Invalid format specifiers in printf-like invocations WT-4805 Modify error message verification for test_prepare04.py WT-4812 Fix the Python distribution script for Python3 changes WT-4818 Add debugging of bad read file descriptor when files are missing during recovery WT-4840 WT_CURSOR.modify must require explicit, snapshot-isolation transaction WT-4864 Coverity: Redundant NULL check WT-4866 Coverity: WT_SESSION.import can leak memory WT-4867 Skip assertion when reserved updates are seen WT-4882 Improve checkpoint performance when there are large metadata pages WT-4887 Skip read timestamp required assert during recovery WT-4888 Remove support for Berkeley DB WT-4891 WT_SESSION.verify memory allocation overrun WT-4895 Fix debug eviction mode so it chooses skew more randomly WT-4910 Port Windows SConstruct to Python 3
Diffstat (limited to 'src/third_party/wiredtiger/src/cursor')
-rw-r--r--src/third_party/wiredtiger/src/cursor/cur_std.c11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/third_party/wiredtiger/src/cursor/cur_std.c b/src/third_party/wiredtiger/src/cursor/cur_std.c
index 808780b4675..073df6eaaf6 100644
--- a/src/third_party/wiredtiger/src/cursor/cur_std.c
+++ b/src/third_party/wiredtiger/src/cursor/cur_std.c
@@ -916,11 +916,16 @@ __cursor_modify(WT_CURSOR *cursor, WT_MODIFY *entries, int nentries)
/*
* The underlying btree code cannot support WT_CURSOR.modify within
* a read-uncommitted transaction. Disallow it here for consistency.
*/
- if (session->txn.isolation == WT_ISO_READ_UNCOMMITTED)
+ if (session->txn.isolation != WT_ISO_SNAPSHOT)
WT_ERR_MSG(session, ENOTSUP,
- "not supported in read-uncommitted transactions");
+ "not supported in read-committed or read-uncommitted "
+ "transactions");
+ if (F_ISSET(&session->txn, WT_TXN_AUTOCOMMIT))
+ WT_ERR_MSG(session, ENOTSUP,
+ "not supported in implicit transactions");
WT_ERR(__cursor_checkkey(cursor));
@@ -916,11 +916,16 @@ __cursor_modify(WT_CURSOR *cursor, WT_MODIFY *entries, int nentries)
/*
* The underlying btree code cannot support WT_CURSOR.modify within
- * a read-uncommitted transaction. Disallow it here for consistency.
+ * a read-committed or read-uncommitted transaction, or outside of
+ * an explicit transaction. Disallow here as well, for consistency.
*/